@@ -12,7 +12,6 @@
 #include <Kdelibs4ConfigMigrator>
 #include "kanjibrowser.h"
 
-static const char description[] = I18N_NOOP( "Kiten's Kanji Browser, a KDE Japanese Reference Tool" );
 static const char version[] = "1.0";
 
 int main( int argc, char **argv )
@@ -27,9 +26,9 @@ int main( int argc, char **argv )
   KLocalizedString::setApplicationDomain("kiten");
 
   KAboutData about( QStringLiteral("kitenkanjibrowser")
-                    , i18n( "kitenkanjibrowser" )
+                    , i18n( "Kanji Browser" )
                     , version
-                    , i18n( description )
+                    , i18n( "Kiten's Kanji Browser, a KDE Japanese Reference Tool" )
                     , KAboutLicense::GPL_V2
                     , i18n( "(C) 2011 Daniel E. Moctezuma" )
                     , QString()
@@ -41,6 +40,10 @@ int main( int argc, char **argv )
   about.setOrganizationDomain( "kde.org" );
 
   KAboutData::setApplicationData(about);
+
+#ifdef Q_OS_WIN
+  QApplication::setStyle(QStringLiteral("breeze"));
+#endif
   
   if( app.isSessionRestored() )
   {
